"use strict";
// Copyright 2018-2022 the Deno authors. All rights reserved. MIT license.
Object.defineProperty(exports, "__esModule", { value: true });
exports.acceptsLanguages = exports.acceptsEncodings = exports.accepts = void 0;
/**
 * Contains the functions {@linkcode accepts}, {@linkcode acceptsEncodings}, and
 * {@linkcode acceptsLanguages} to provide content negotiation capabilities.
 *
 * @module
 */
const encoding_js_1 = require("./_negotiation/encoding.js");
const language_js_1 = require("./_negotiation/language.js");
const media_type_js_1 = require("./_negotiation/media_type.js");
function accepts(request, ...types) {
    const accept = request.headers.get("accept");
    return types.length
        ? accept ? (0, media_type_js_1.preferredMediaTypes)(accept, types)[0] : types[0]
        : accept
            ? (0, media_type_js_1.preferredMediaTypes)(accept)
            : ["*/*"];
}
exports.accepts = accepts;
function acceptsEncodings(request, ...encodings) {
    const acceptEncoding = request.headers.get("accept-encoding");
    return encodings.length
        ? acceptEncoding
            ? (0, encoding_js_1.preferredEncodings)(acceptEncoding, encodings)[0]
            : encodings[0]
        : acceptEncoding
            ? (0, encoding_js_1.preferredEncodings)(acceptEncoding)
            : ["*"];
}
exports.acceptsEncodings = acceptsEncodings;
function acceptsLanguages(request, ...langs) {
    const acceptLanguage = request.headers.get("accept-language");
    return langs.length
        ? acceptLanguage ? (0, language_js_1.preferredLanguages)(acceptLanguage, langs)[0] : langs[0]
        : acceptLanguage
            ? (0, language_js_1.preferredLanguages)(acceptLanguage)
            : ["*"];
}
exports.acceptsLanguages = acceptsLanguages;
