"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateRequest = void 0;
const deps_js_1 = require("./deps.js");
/** Validate the request is valid GraphQL playground request or not. */
function validateRequest(req) {
    if (req.method !== "GET") {
        return [
            false,
            (0, deps_js_1.createHttpError)(deps_js_1.Status.MethodNotAllowed, `Invalid HTTP request method. ${req.method}`, { headers: { allow: "GET" } }),
        ];
    }
    if (req.headers.has("accept"))
        return [true];
    const headers = { vary: "accept" };
    const mediaType = (0, deps_js_1.accepts)(req, "text/html");
    if (mediaType !== "text/html") {
        return [
            false,
            (0, deps_js_1.createHttpError)(deps_js_1.Status.NotAcceptable, `text/html`, { expose: true, headers }),
        ];
    }
    return [true, { headers }];
}
exports.validateRequest = validateRequest;
